@@ -20,6 +20,7 @@ import time
 import numpy as np
 from tqdm import trange
 import networkx as nx
+import trimesh
 from sage.all import polytopes, QQ, RR, Polyhedron
 
 from .logger import attach_to_log
@@ -497,7 +498,7 @@ class CellComplex:
         """
         Visualise the cells using trimesh.
 
-        Trimesh/pyglet installation are needed for the visualisation.
+        pyglet installation is needed for the visualisation.
 
         Parameters
         ----------
@@ -510,11 +511,12 @@ class CellComplex:
             import os
             import string
             try:
-                import trimesh
                 import pyglet
             except ImportError:
-                logger.warning('trimesh/pyglet installation not found; skip visualisation')
+                logger.warning('pyglet installation not found; skip visualisation')
                 return
+            if indices_cells is not None and len(indices_cells) == 0:
+                raise ValueError('no indices provided')
             temp_filename = ''.join(choices(string.ascii_uppercase + string.digits, k=5)) + '.obj'
             self.save_obj(filepath=temp_dir + temp_filename, indices_cells=indices_cells, use_mtl=True)
             scene = trimesh.load_mesh(temp_dir + temp_filename)
@@ -547,7 +549,7 @@ class CellComplex:
         multiplier: float
             Multiplier to the volume
         engine: str
-            Engine to compute volumes, can be 'Qhull' or 'native' with native SageMath
+            Engine to compute volumes, can be 'Qhull' or 'Sage' with native SageMath
 
         Returns
         -------
@@ -565,11 +567,11 @@ class CellComplex:
                     volumes[i] = RR(cell.volume()) * multiplier
             return volumes
 
-        elif engine == 'native':
+        elif engine == 'Sage':
             return [RR(cell.volume()) * multiplier for cell in self.cells]
 
         else:
-            raise ValueError('engine must be either "Qhull" or "native"')
+            raise ValueError('engine must be either "Qhull" or "Sage"')
 
     def cell_representatives(self, location='center'):
         """
@@ -591,7 +593,44 @@ class CellComplex:
         elif location == 'centroid':
             return [cell.centroid() for cell in self.cells]
         else:
-            raise ValueError("expected 'mass' or 'centroid' as mode, got {}".format(location))
+            raise ValueError("expected 'center' or 'centroid' as mode, got {}".format(location))
+
+    def cells_in_mesh(self, filepath_mesh, engine='ray'):
+        """
+        Return indices of cells that are inside a reference mesh.
+
+        Parameters
+        ----------
+        filepath_mesh: str
+            Filepath to reference mesh
+        engine: str
+            Engine to compute predicate, can be 'ray' for ray intersection, or 'distance' for signed distance
+
+        Returns
+        -------
+        as_int: (n, ) int
+            Indices of cells being inside the reference mesh
+        """
+        mesh = trimesh.load_mesh(filepath_mesh)
+        centers = self.cell_representatives(location='center')
+
+        if engine == 'ray':
+            # raytracing not stable for non-watertight mesh (incl. with inner structure)
+            try:
+                # https://trimsh.org/trimesh.ray.ray_pyembree.html
+                contains = trimesh.ray.ray_pyembree.RayMeshIntersector(mesh).contains_points(centers)
+            except ModuleNotFoundError:
+                # https://trimsh.org/trimesh.ray.ray_triangle.html
+                logger.warning('pyembree installation not found; fall back to ray_triangle')
+                contains = mesh.contains(centers)
+            return contains.nonzero()[0]
+
+        elif engine == 'distance':
+            # https://trimsh.org/trimesh.proximity.html
+            distances = trimesh.proximity.signed_distance(mesh, centers)
+            return (distances >= 0).nonzero()[0]
+        else:
+            raise ValueError("expected 'ray' or 'distance' as engine, got {}".format(engine))
 
     def print_info(self):
         """
@@ -642,6 +681,8 @@ class CellComplex:
 
         # directly save the obj string from scene.obj() will bring the inverted facets
         scene_obj = scene.obj_repr(scene.default_render_params())
+        if len(cells) == 1:
+            scene_obj = [scene_obj]
         scene_str = ''
         material_str = ''
 
